@@ -2,6 +2,7 @@ import os
 from dotenv import load_dotenv
 load_dotenv()
 from fudstop.apis.polygonio.polygon_options import PolygonOptions
+from fudstop.apis.polygonio.polygon_database import PolygonDatabase
 from apis.polygonio.async_polygon_sdk import Polygon
 from fudstop._markets.list_sets.ticker_lists import most_active_tickers
 import numpy as np
@@ -9,8 +10,12 @@ import pandas as pd
 import asyncio
 import requests
 from datetime import datetime, timezone, timedelta
-poly = Polygon(host='localhost', user='chuck', database='polygon', password='fud', port=5432)
-
+poly = Polygon(host='localhost', user='chuck', database='markets', password='fud', port=5432)
+db = Polygon(host='localhost', user='chuck', database='markets', password='fud', port=5432)
+today = datetime.now().strftime('%Y-%m-%d')
+yesterday = (datetime.now() - timedelta(days=1)).strftime('%Y-%m-%d')
+thirty_days_ago = (datetime.now() - timedelta(days=30)).strftime('%Y-%m-%d')
+tomorrow = (datetime.now() + timedelta(days=1)).strftime('%Y-%m-%d')
 ticker='AMZN'
 timespan='day'
 window=50
@@ -18,8 +23,8 @@ limit=100
 timeframe='quarterly'
 
 multiplier = 1
-date_from = '2023-12-01'
-date_to = '2023-12-29'
+date_from = thirty_days_ago
+date_to = today
 
 
 class PolygonMaster:
@@ -363,6 +368,9 @@ class PolygonMaster:
         if 'ticker' in self.kwargs:
             # Add the ticker as a new column
             self.agg_as_dataframe['ticker'] = self.kwargs['ticker']
+
+
+        return self.agg_as_dataframe
             
 
     def process_ema_results(self, ema_results):
@@ -391,7 +399,7 @@ class PolygonMaster:
             # Add the ticker as a new column
             self.ema_as_dataframe['ticker'] = self.kwargs['ticker']
             
-
+        return self.ema_as_dataframe
     def process_sma_results(self, sma_results):
         self.underlying = sma_results.get('underlying')
         self.sma_values = sma_results.get('values')
@@ -420,6 +428,7 @@ class PolygonMaster:
             # Add the ticker as a new column
             self.sma_as_dataframe['ticker'] = self.kwargs['ticker']
 
+        return self.sma_as_dataframe
     # def process_single_snapshot_results(self, ticker_snapshot_results):
     #     self.ticker = ticker_snapshot_results['ticker']
     #     self.todaysChangePerc= float(ticker_snapshot_results['todaysChangePerc']) if ticker_snapshot_results['todaysChangePerc'] is not None else 'N/A'
@@ -603,7 +612,7 @@ class PolygonMaster:
 
         self.ticker_news_as_dataframe = pd.DataFrame(self.ticker_news_data_dict)
 
-
+        return self.ticker_news_as_dataframe
 
     def process_annual_financial_results(self, financials_results):
         self.id = []
@@ -795,7 +804,7 @@ class PolygonMaster:
             self.as_financials_df['ticker'] = self.kwargs['ticker']
             
 
-
+        return self.as_financials_df
 
     def convert_timestamp(self, timestamp, from_milliseconds=True):
         try:
@@ -813,6 +822,8 @@ class PolygonMaster:
         for key, value in params.items():
             full_url += f"&{key}={value}"
         response = requests.get(full_url)
+        print(full_url)
+        print(response)
         return response.json().get('results')
         
 
@@ -820,6 +831,7 @@ class PolygonMaster:
         endpoint = f"/v1/indicators/rsi/{ticker}"
         params = {"timespan": timespan, "adjusted": "true", "window": 14, "order": "desc", "limit": limit}
         rsi_response = self.make_polygon_request(endpoint, params)
+        print(rsi_response)
         return PolygonMaster(rsi_results=rsi_response, ticker=ticker)
     
     def get_macd(self, ticker, timespan, limit):
@@ -849,6 +861,7 @@ class PolygonMaster:
         endpoint = f"/v2/aggs/ticker/{ticker}/range/{multiplier}/{timespan}/{date_from}/{date_to}"
         params = {"adjusted": "true", "sort": "asc", "limit": limit}
         aggregates_response = self.make_polygon_request(endpoint, params)
+        print(aggregates_response)
         return PolygonMaster(aggregates_results=aggregates_response, ticker=ticker)
 
     def get_ticker_news(self, ticker):
@@ -865,17 +878,18 @@ class PolygonMaster:
     
 
 master = PolygonMaster()
-opts = PolygonOptions(user='chuck', database='polygon', host='localhost', password='fud', port=5432)
+opts = PolygonOptions(user='chuck', database='markets', host='localhost', password='fud', port=5432)
+db = PolygonDatabase(host='localhost', user='chuck', database='markets', password='fud', port=5432)
 async def main(ticker):
     ticker=ticker
     timespan='day'
     multiplier=1
-    date_to = '2023-01-01'
-    date_from = '2024-01-12'
+    date_to = today
+    date_from = thirty_days_ago
     limit=1000
     try:
         rsi = master.get_rsi(ticker=ticker,timespan=timespan, limit=limit)
-        
+
         aggs = master.get_aggregates(ticker,multiplier,timespan,date_from,date_to,limit)
         financials = master.get_financials(ticker,timeframe='quarterly')
         ema = master.get_ema(ticker,timespan,window,limit)
@@ -884,15 +898,15 @@ async def main(ticker):
         news = master.get_ticker_news(ticker)
         
 
-        await opts.connect()
-
-        await opts.batch_insert_dataframe(rsi.rsi_as_dataframe,table_name='rsi', unique_columns='rsi_timespan, rsi_timestamp, ticker')
-        await opts.batch_insert_dataframe(aggs.agg_as_dataframe, table_name='aggs', unique_columns='agg_timespan, agg_timestamp, ticker')
-        await opts.batch_insert_dataframe(financials.as_financials_df, table_name='financials', unique_columns='ticker')
-        await opts.batch_insert_dataframe(ema.ema_as_dataframe, table_name='ema', unique_columns='ticker')
-        await opts.batch_insert_dataframe(sma.sma_as_dataframe, table_name='sma', unique_columns='ticker')
-        await opts.batch_insert_dataframe(macd.macd_as_dataframe, table_name='macd', unique_columns='ticker')
-        await opts.batch_insert_dataframe(news.ticker_news_as_dataframe, table_name='news', unique_columns='insertion_timestamp')
+        await db.connect()
+        
+        await db.batch_insert_dataframe(rsi.rsi_as_dataframe.fillna(''),table_name='rsi', unique_columns='rsi_timespan, rsi_timestamp, ticker')
+        await db.batch_insert_dataframe(aggs.agg_as_dataframe.fillna(''), table_name='aggs', unique_columns='agg_timespan, agg_timestamp, ticker')
+        await db.batch_insert_dataframe(financials.as_financials_df.fillna(''), table_name='financials', unique_columns='ticker')
+        await db.batch_insert_dataframe(ema.ema_as_dataframe.fillna(''), table_name='ema', unique_columns='ticker')
+        await db.batch_insert_dataframe(sma.sma_as_dataframe.fillna(''), table_name='sma', unique_columns='ticker')
+        await db.batch_insert_dataframe(macd.macd_as_dataframe.fillna(''), table_name='macd', unique_columns='ticker')
+        await db.batch_insert_dataframe(news.ticker_news_as_dataframe.fillna(''), table_name='news', unique_columns='insertion_timestamp')
         #await opts.batch_insert_dataframe(snapshots.all_ticker_snapshots_as_dataframe, table_name='snapshot', unique_columns='insertion_timestamp')
     except Exception as e:
         print(f"Error for {ticker} - {e} - skipping..")
