@@ -20,7 +20,7 @@ from apis.helpers import calculate_countdown, calculate_setup
 from aiohttp.client_exceptions import ClientConnectorError, ClientOSError
 import aiohttp
 from asyncio import Semaphore
-from webull_options.webull_options import WebullOptions
+from fudstop.apis.webull.webull_options.webull_options import WebullOptions
 from db_manager import DbManager as DatabaseManager
 sema = Semaphore(10)
 db = DatabaseManager(host='localhost', port=5432, user='chuck', password='fud', database='markets')
