@@ -7,7 +7,7 @@ from pathlib import Path
 project_dir = str(Path(__file__).resolve().parents[1])
 if project_dir not in sys.path:
     sys.path.append(project_dir)
-from webull_options.webull_options import WebullOptions
+from fudstop.apis.webull.webull_options.webull_options import WebullOptions
 
 db = WebullOptions(database='markets', user='chuck')
 
