@@ -13,7 +13,7 @@ from _markets.webhook_dicts import option_conditions_hooks
 from _markets.embeddings import sized_trade_embed, specials_embed_2, dip_specials_embed, index_surge_embed, dip_specials_embed_2_super, theta_resistant_embed
 from polygon.websocket import WebSocketClient, WebSocketMessage, Market, Feed
 from apis.polygonio.polygon_options import PolygonOptions
-from webull_options.webull_options import WebullOptions
+from fudstop.apis.webull.webull_options.webull_options import WebullOptions
 
 
 
