@@ -184,6 +184,25 @@ def human_readable(string):
     strike_price = '${:.2f}'.format(float(strike_price)/1000)
     return "{} {} {} Expiring {}".format(underlying_symbol, strike_price, call_put, expiry_date)
 
+def clean_html(html_content):
+    # Parse HTML content using BeautifulSoup
+    soup = BeautifulSoup(html_content, 'html.parser')
+    
+    # Extract text from the parsed HTML
+    text = soup.get_text(separator=' ')
+    
+    # Replace HTML entities and other non-alphanumeric characters
+    text = re.sub(r'&#\d+;', '', text)  # Remove HTML encoded numerics like '&#160;'
+    text = re.sub(r'[\r\n\t]+', '\n', text)  # Replace multiple newlines/tabs with a single newline
+    text = re.sub(r' +', ' ', text)  # Replace multiple spaces with a single space
+    text = re.sub(r'\n +', '\n', text)  # Remove spaces following newlines
+    text = re.sub(r'[^\x00-\x7F]+', ' ', text)  # Remove non-ASCII characters
+    text = re.sub(r'Page \d+', '', text)  # Optional: Remove page numbers
+    
+    # Clean up specific case-related wording
+    text = text.replace('P>', '').replace('<P', '').strip()  # Removing remnants of <P> tags if any
+
+    return text
 @staticmethod
 def get_human_readable_string(string):
     result = {}
