@@ -25,7 +25,7 @@ from apis.fed_print.fedprint_sdk import FedPrint
 from apis.earnings_whisper.ew_sdk import EarningsWhisper
 from apis.federal_register.fed_register_sdk import FedRegisterSDK
 from apis.treasury.treasury_sdk import Treasury
-from webull_options.webull_options import WebullOptions
+from fudstop.apis.webull.webull_options.webull_options import WebullOptions
 from datetime import datetime, timedelta
 from openai import OpenAI
 import httpx
@@ -210,7 +210,7 @@ class MasterSDK:
         return df.head(limit).to_dict('records')
     async def webull_capital_flow(self, ticker, limit:int=3, insert:bool=False):
         """Gets capital flow data broken down by player size for a ticker."""
-        data = await self.trading.capital_flow(ticker)
+        data, HISTORIC = await self.trading.capital_flow(ticker)
         df = data.df
         df['ticker'] = ticker
         if insert == True:
