@@ -36,7 +36,7 @@ YOUR_POLYGON_KEY = os.environ.get('YOUR_POLYGON_KEY')
 
 session = requests.session()
 class Polygon:
-    def __init__(self, host, port, user, password, database):
+    def __init__(self, host='localhost', user='chuck', database='market_data', password='fud', port=5432):
         self.host=host
         self.port=port
         self.user=user
@@ -448,15 +448,17 @@ class Polygon:
             if date_to is None:
                 date_to = self.today
 
-
-            endpoint = f"https://api.polygon.io/v1/indicators/rsi/{ticker}?timespan={timespan}&timestamp.gte={date_from}&timestamp.lte={date_to}&limit={limit}&window={window}&apiKey={self.api_key}"
+            if timespan == 'month':
+                date_from = self.thirty_days_ago
+            
+            endpoint = f"https://api.polygon.io/v1/indicators/rsi/{ticker}?timespan={timespan}&timestamp.gte={date_from}&timestamp.lte={date_to}&limit={limit}&window={window}&expand_underlying=true&apiKey={self.api_key}"
     
 
             async with aiohttp.ClientSession() as session:
                 try:
                     async with session.get(endpoint) as response:
                         datas = await response.json()
-                        print(datas)
+                      
                         if datas is not None:
 
                             
@@ -476,7 +478,16 @@ class Polygon:
             print(e)
 
 
+    async def get_cik(self, ticker):
 
+        endpoint = f"https://api.polygon.io/v3/reference/tickers/{ticker}?apiKey={os.environ.get('YOUR_POLYGON_KEY')}"
+        async with httpx.AsyncClient() as client:
+            data = await client.get(endpoint)
+
+            cik = data.json()['results']['cik']
+
+            
+            return cik
 
     async def macd(self, ticker:str, timespan:str, limit:str='1000'):
         """
@@ -665,11 +676,12 @@ class Polygon:
             rsis = {}
             rsis.update({'ticker': ticker,
                         'price': price})
+            minrsi = asyncio.create_task(self.rsi(ticker,timespan='minute'))
             drsi = asyncio.create_task(self.rsi(ticker, timespan='day'))
             hrsi = asyncio.create_task(self.rsi(ticker, timespan='hour'))
             wrsi = asyncio.create_task(self.rsi(ticker, timespan='week'))
             mrsi = asyncio.create_task(self.rsi(ticker, timespan='month'))
-            day_rsi, hour_rsi, week_rsi, month_rsi = await asyncio.gather(drsi, hrsi, wrsi, mrsi)
+            day_rsi, hour_rsi, week_rsi, month_rsi, minute_rsi = await asyncio.gather(drsi, hrsi, wrsi, mrsi, minrsi)
             if day_rsi is not None and hasattr(day_rsi, 'rsi_value') and day_rsi.rsi_value is not None and len(day_rsi.rsi_value) > 0:
                 day_rsi = day_rsi.rsi_value[0]
 
@@ -687,6 +699,11 @@ class Polygon:
                 month_rsi = month_rsi.rsi_value[0]
                 rsis.update({'month_rsi': month_rsi})
 
+
+            if minute_rsi is not None and hasattr(minute_rsi, 'rsi_value') and minute_rsi.rsi_value is not None and len(minute_rsi.rsi_value) > 0:
+                minute_rsi = minute_rsi.rsi_value[0]
+                rsis.update({'minute_rsi': minute_rsi})
+
             
             df = pd.DataFrame(rsis, index=[0])
 
