@@ -295,7 +295,7 @@ class UniversalOptionSnapshot:
         self.return_on_risk = [float(p) / (float(s) - float(u)) if ct == 'call' and p is not None and s is not None and u is not None and s > u else float(p) / (float(u) - float(s)) if ct == 'put' and p is not None and s is not None and u is not None and s < u else 0.0 for ct, p, s, u in zip(self.contract_type, self.trade_price, self.strike, self.underlying_price)]
         self.return_on_risk = [round(item, 3) if item is not None else None for item in self.return_on_risk]
         self.option_velocity = [float(delta) / float(p) if delta is not None and p is not None else 0.0 for delta, p in zip(self.delta, self.trade_price)]
-        self.option_velocity =[round(item, 3) if item is not None else None for item in self.option_velocity]
+        self.option_velocity = [round(item, 3) if item is not None else None for item in self.option_velocity]
         self.gamma_risk = [float(g) * float(u) if g is not None and u is not None else None for g, u in zip(self.gamma, self.underlying_price)]
         self.gamma_risk =[round(item, 3) if item is not None else None for item in self.gamma_risk]
         self.theta_decay_rate = [float(t) / float(p) if t is not None and p is not None else None for t, p in zip(self.theta, self.trade_price)]
@@ -304,39 +304,38 @@ class UniversalOptionSnapshot:
         self.vega_impact =[round(item, 3) if item is not None else None for item in self.vega_impact]
         self.delta_to_theta_ratio = [float(d) / float(t) if d is not None and t is not None and t != 0 else None for d, t in zip(self.delta, self.theta)]
         self.delta_to_theta_ratio = [round(item, 3) if item is not None else None for item in self.delta_to_theta_ratio]
-        #option_sensitivity score - curated - finished
+
+        # Option sensitivity score - curated - finished
         self.oss = [(float(delta) if delta is not None else 0) + (0.5 * float(gamma) if gamma is not None else 0) + (0.1 * float(vega) if vega is not None else 0) - (0.5 * float(theta) if theta is not None else 0) for delta, gamma, vega, theta in zip(self.delta, self.gamma, self.vega, self.theta)]
         self.oss = [round(item, 3) for item in self.oss]
-        #liquidity-theta ratio - curated - finished
+
+        # Liquidity-theta ratio - curated - finished
         self.ltr = [liquidity / abs(theta) if liquidity and theta else None for liquidity, theta in zip(self.liquidity_indicator, self.theta)]
-        #risk-reward score - curated - finished
+
+        # Risk-reward score - curated - finished
         self.rrs = [(intrinsic + extrinsic) / (iv + 1e-4) if intrinsic and extrinsic and iv else None for intrinsic, extrinsic, iv in zip(self.intrinsic_value, self.extrinsic_value, self.implied_volatility)]
-        #greeks-balance score - curated - finished
+
+        # Greeks-balance score - curated - finished
         self.gbs = [(abs(delta) if delta else 0) + (abs(gamma) if gamma else 0) - (abs(vega) if vega else 0) - (abs(theta) if theta else 0) for delta, gamma, vega, theta in zip(self.delta, self.gamma, self.vega, self.theta)]
         self.gbs = [round(item, 3) if item is not None else None for item in self.gbs]
-        #options profit potential: FINAL - finished
-        self.opp = [moneyness_score*oss*ltr*rrs if moneyness_score and oss and ltr and rrs else None for moneyness_score, oss, ltr, rrs in zip([1 if m == 'ITM' else 0.5 if m == 'ATM' else 0.2 for m in self.moneyness], self.oss, self.ltr, self.rrs)]
-        self.opp = [round(item, 3) if item is not None else None for item in self.opp]
 
+        # Options profit potential: FINAL - finished
+        self.opp = [moneyness_score * oss * ltr * rrs if moneyness_score and oss and ltr and rrs else None for moneyness_score, oss, ltr, rrs in zip([1 if m == 'ITM' else 0.5 if m == 'ATM' else 0.2 for m in self.moneyness], self.oss, self.ltr, self.rrs)]
+        self.opp = [round(item, 3) if item is not None else None for item in self.opp]
 
         iv_series = pd.Series(self.implied_volatility).dropna()
         self.iv_percentile = [round(x, 2) for x in iv_series.rank(pct=True)]
-                
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
+        # Add additional second and third order Greeks
+        # Add additional second and third order Greeks
+        self.vanna = [(v * d) / 100 if v is not None and d is not None else None for v, d in zip(self.vega, self.delta)]
+        self.vomma = [(v * (d * (1 - d))) / 10000 if v is not None and d is not None else None for v, d in zip(self.vega, self.delta)]
+        self.charm = [(d * t) / 365 if d is not None and t is not None else None for d, t in zip(self.delta, self.days_to_expiry_series)]
+        self.veta = [(v * (d - 0.5)) if v is not None and d is not None else None for v, d in zip(self.vega, self.delta)]
+        self.speed = [(g * d) / 100 if g is not None and d is not None else None for g, d in zip(self.gamma, self.delta)]
+        self.zomma = [(g * (d - 0.5)) if g is not None and d is not None else None for g, d in zip(self.gamma, self.delta)]
+        self.color = [(g * t) / 365 if g is not None and t is not None else None for g, t in zip(self.gamma, self.days_to_expiry_series)]
+        self.ultima = [(v * (3 * d ** 2 - 2 * d + 1)) / 1000000 if v is not None and d is not None else None for v, d in zip(self.vega, self.delta)]
 
         self.data_dict = {
             'strike': self.strike,
@@ -345,8 +344,8 @@ class UniversalOptionSnapshot:
             'time_value': self.time_value,
             'moneyness': self.moneyness,
             'liquidity_score': self.liquidity_indicator,
-            "cp": self.contract_type,
-            "change_ratio": self.change_percent,
+            'cp': self.contract_type,
+            'change_ratio': self.change_percent,
             'exercise_style': self.exercise_style,
             'option_symbol': self.ticker,
             'theta': self.theta,
@@ -363,10 +362,10 @@ class UniversalOptionSnapshot:
             'high': self.high,
             'low': self.low,
             'close': self.close,
-            'intrinstic_value': self.intrinsic_value,
+            'intrinsic_value': self.intrinsic_value,
             'extrinsic_value': self.extrinsic_value,
             'leverage_ratio': self.leverage_ratio,
-            'vwap':self.vwap,
+            'vwap': self.vwap,
             'conditions': self.conditions,
             'price': self.trade_price,
             'trade_size': self.trade_size,
@@ -387,58 +386,66 @@ class UniversalOptionSnapshot:
             'velocity': self.option_velocity,
             'sensitivity': self.oss,
             'greeks_balance': self.gbs,
-            'opp': self.opp
-            
+            'opp': self.opp,
+            'vanna': self.vanna,
+            'vomma': self.vomma,
+            'charm': self.charm,
+            'veta': self.veta,
+            'speed': self.speed,
+            'zomma': self.zomma,
+            'color': self.color,
+            'ultima': self.ultima
         }
 
-
         # Create DataFrame from data_dict
         self.df = pd.DataFrame(self.data_dict)
-    def __repr__(self) -> str:
-        return f"UniversalOptionSnapshot(break_even={self.break_even}, \
-                implied_volatility={self.implied_volatility},\
-                open_interest ={self.open_interest}, \
-                change={self.exchange}, \
-                expiry={self.expiry}, \
-                ticker={self.ticker} \
-                contract_type={self.contract_type}, \
-                exercise_style={self.exercise_style}, \
-                theta={self.theta}, \
-                delta={self.delta}, \
-                gamma={self.gamma}, \
-                vega={self.vega}, \
-                sip_timestamp={self.sip_timestamp}, \
-                conditions={self.conditions}, \
-                trade_price={self.trade_price}, \
-                trade_size={self.trade_size}, \
-                exchange={self.exchange}, \
-                ask={self.ask}, \
-                bid={self.bid}, \
-                bid_size={self.bid_size}, \
-                ask_size={self.ask_size}, \
-                midpoint={self.midpoint}, \
-                change_to_breakeven={self.change_to_breakeven}, \
-                underlying_price={self.underlying_price}, \
-                underlying_ticker={self.underlying_ticker})"
-    
-    def __getitem__(self, index):
-        return self.df[index]
 
-    def __setitem__(self, index, value):
-        self.df[index] = value
-    def __iter__(self):
-        # If df is a DataFrame, it's already iterable (over its column labels)
-        # To iterate over rows, use itertuples or iterrows
-        self.iter = self.df.itertuples()
-        return self
+        def __repr__(self) -> str:
+            return f"UniversalOptionSnapshot(break_even={self.break_even}, \
+                    implied_volatility={self.implied_volatility},\
+                    open_interest ={self.open_interest}, \
+                    change={self.exchange}, \
+                    expiry={self.expiry}, \
+                    ticker={self.ticker} \
+                    contract_type={self.contract_type}, \
+                    exercise_style={self.exercise_style}, \
+                    theta={self.theta}, \
+                    delta={self.delta}, \
+                    gamma={self.gamma}, \
+                    vega={self.vega}, \
+                    sip_timestamp={self.sip_timestamp}, \
+                    conditions={self.conditions}, \
+                    trade_price={self.trade_price}, \
+                    trade_size={self.trade_size}, \
+                    exchange={self.exchange}, \
+                    ask={self.ask}, \
+                    bid={self.bid}, \
+                    bid_size={self.bid_size}, \
+                    ask_size={self.ask_size}, \
+                    midpoint={self.midpoint}, \
+                    change_to_breakeven={self.change_to_breakeven}, \
+                    underlying_price={self.underlying_price}, \
+                    underlying_ticker={self.underlying_ticker})"
 
-    def __next__(self):
-        # Just return the next value from the DataFrame iterator
-        try:
-            return next(self.iter)
-        except StopIteration:
-            # When there are no more rows, stop iteration
-            raise StopIteration
+        def __getitem__(self, index):
+            return self.df[index]
+
+        def __setitem__(self, index, value):
+            self.df[index] = value
+
+        def __iter__(self):
+            # If df is a DataFrame, it's already iterable (over its column labels)
+            # To iterate over rows, use itertuples or iterrows
+            self.iter = self.df.itertuples()
+            return self
+
+        def __next__(self):
+            # Just return the next value from the DataFrame iterator
+            try:
+                return next(self.iter)
+            except StopIteration:
+                # When there are no more rows, stop iteration
+                raise StopIteration
 
 class CallsOrPuts:
     def __init__(self, data):
