@@ -160,6 +160,11 @@ class PolygonOptions:
         self.pool = await asyncpg.create_pool(host=self.host, user=self.user,port=self.port,database=self.database,password=self.password)
 
         return self.pool
+    
+    async def disconnect(self):
+        if self.pool:
+            await self.pool.close()
+            self.pool = None
     async def update_options(self, ticker):
         all_options = await self.find_symbols(ticker)
         df = all_options.df
@@ -689,82 +694,83 @@ class PolygonOptions:
         async with lock:
             if not await self.table_exists(table_name):
                 await self.create_table(df, table_name, unique_columns)
-
-            # Debug: Print DataFrame columns before modifications
-            #print("Initial DataFrame columns:", df.columns.tolist())
-            
-            df = df.copy()
-            
-            df['insertion_timestamp'] = pd.to_datetime([datetime.now() for _ in range(len(df))])
+            try:
+                # Debug: Print DataFrame columns before modifications
+                #print("Initial DataFrame columns:", df.columns.tolist())
+                
+                df = df.copy()
+                
+                df['insertion_timestamp'] = pd.to_datetime([datetime.now() for _ in range(len(df))])
 
 
-            # Debug: Print DataFrame columns after modifications
-            #print("Modified DataFrame columns:", df.columns.tolist())
-            
-            records = df.to_records(index=False)
-            data = list(records)
+                # Debug: Print DataFrame columns after modifications
+                #print("Modified DataFrame columns:", df.columns.tolist())
+                
+                records = df.to_records(index=False)
+                data = list(records)
 
 
-            async with self.pool.acquire() as connection:
-                column_types = await connection.fetch(
-                    f"SELECT column_name, data_type FROM information_schema.columns WHERE table_name = '{table_name}'"
-                )
-                type_mapping = {col: next((item['data_type'] for item in column_types if item['column_name'] == col), None) for col in df.columns}
+                async with self.pool.acquire() as connection:
+                    column_types = await connection.fetch(
+                        f"SELECT column_name, data_type FROM information_schema.columns WHERE table_name = '{table_name}'"
+                    )
+                    type_mapping = {col: next((item['data_type'] for item in column_types if item['column_name'] == col), None) for col in df.columns}
 
-                async with connection.transaction():
-                    insert_query = f"""
-                    INSERT INTO {table_name} ({', '.join(f'"{col}"' for col in df.columns)}) 
-                    VALUES ({', '.join('$' + str(i) for i in range(1, len(df.columns) + 1))})
-                    ON CONFLICT ({unique_columns})
-                    DO UPDATE SET {', '.join(f'"{col}" = excluded."{col}"' for col in df.columns)}
-                    """
-            
-                    batch_data = []
-                    for record in data:
-                        new_record = []
-                        for col, val in zip(df.columns, record):
-                            pg_type = type_mapping[col]
+                    async with connection.transaction():
+                        insert_query = f"""
+                        INSERT INTO {table_name} ({', '.join(f'"{col}"' for col in df.columns)}) 
+                        VALUES ({', '.join('$' + str(i) for i in range(1, len(df.columns) + 1))})
+                        ON CONFLICT ({unique_columns})
+                        DO UPDATE SET {', '.join(f'"{col}" = excluded."{col}"' for col in df.columns)}
+                        """
+                
+                        batch_data = []
+                        for record in data:
+                            new_record = []
+                            for col, val in zip(df.columns, record):
+                                pg_type = type_mapping[col]
 
-                            if val is None:
-                                new_record.append(None)
-                            elif pg_type in ['timestamp', 'timestamp without time zone', 'timestamp with time zone']:
-                                if isinstance(val, np.datetime64):
-                                    # Convert numpy datetime64 to Python datetime, ensure UTC and remove tzinfo if needed
-                                    new_record.append(pd.Timestamp(val).to_pydatetime().replace(tzinfo=None))
-                                elif isinstance(val, datetime):
-                                    # Directly use the Python datetime object
+                                if val is None:
+                                    new_record.append(None)
+                                elif pg_type in ['timestamp', 'timestamp without time zone', 'timestamp with time zone']:
+                                    if isinstance(val, np.datetime64):
+                                        # Convert numpy datetime64 to Python datetime, ensure UTC and remove tzinfo if needed
+                                        new_record.append(pd.Timestamp(val).to_pydatetime().replace(tzinfo=None))
+                                    elif isinstance(val, datetime):
+                                        # Directly use the Python datetime object
+                                        new_record.append(val)
+                                elif pg_type in ['double precision', 'real'] and not isinstance(val, str):
+                                    new_record.append(float(val))
+                                elif isinstance(val, np.int64):
+                                    new_record.append(int(val))
+                                elif pg_type == 'integer' and not isinstance(val, int):
+                                    new_record.append(int(val))
+                                else:
                                     new_record.append(val)
-                            elif pg_type in ['double precision', 'real'] and not isinstance(val, str):
-                                new_record.append(float(val))
-                            elif isinstance(val, np.int64):
-                                new_record.append(int(val))
-                            elif pg_type == 'integer' and not isinstance(val, int):
-                                new_record.append(int(val))
-                            else:
-                                new_record.append(val)
-                    
-                        batch_data.append(new_record)
+                        
+                            batch_data.append(new_record)
 
-                        if len(batch_data) == batch_size:
-                            try:
+                            if len(batch_data) == batch_size:
+                                try:
+                                    
                                 
-                             
+                                    await connection.executemany(insert_query, batch_data)
+                                    batch_data.clear()
+                                except Exception as e:
+                                    print(f"An error occurred while inserting the record: {e}")
+                                    await connection.execute('ROLLBACK')
+                        
+                        if batch_data:
+                            # Convert all elements in batch_data to strings
+                            #batch_data = [[str(value) if isinstance(value, float) else value for value in row] for row in batch_data]
+                            
+                            try:
                                 await connection.executemany(insert_query, batch_data)
-                                batch_data.clear()
                             except Exception as e:
                                 print(f"An error occurred while inserting the record: {e}")
                                 await connection.execute('ROLLBACK')
-                    
-                    if batch_data:
-                        # Convert all elements in batch_data to strings
-                        #batch_data = [[str(value) if isinstance(value, float) else value for value in row] for row in batch_data]
-                        
-                        try:
-                            await connection.executemany(insert_query, batch_data)
-                        except Exception as e:
-                            print(f"An error occurred while inserting the record: {e}")
-                            await connection.execute('ROLLBACK')
-                            
+            except Exception as e:
+                print(e)
     async def save_to_history(self, df, main_table_name, history_table_name):
         # Assume the DataFrame `df` contains the records to be archived
         if not await self.table_exists(history_table_name):
@@ -1277,7 +1283,7 @@ class PolygonOptions:
 
     async def chunk_250(self, all_options: UniversalOptionSnapshot):
         """Chunks all options into sizes of 250"""
-        # Calculate the number of chunks
+        # Calculate the number of chunksF
         total_items = len(all_options.ticker)  # Replace with the actual length of all_options
         chunk_size = 250
         num_chunks = (total_items + chunk_size - 1) // chunk_size  # Calculate the total number of chunks
