@@ -17,9 +17,9 @@ from tabulate import tabulate
 from asyncpg.exceptions import UniqueViolationError
 from selenium import webdriver
 from selenium.webdriver.chrome.options import Options
-from apis.webull.webull_screener import WebulScreener, ScreenerSelect
+from fudstop.apis.webull.webull_paper_trader import WebulScreener, ScreenerSelect
 from datetime import datetime
-from apis.openai_ import OpenAISDK
+
 from apis.polygonio.polygon_options import PolygonOptions
 import disnake
 from apis.y_finance.yf_sdk import yfSDK
